Dask-Yarn
=========

|travis| |readthedocs| |pypi| |conda|

Dask-Yarn deploys Dask on `YARN
<https://hadoop.apache.org/docs/current/hadoop-yarn/hadoop-yarn-site/YARN.html>`_
clusters, such as are found in traditional Hadoop installations. Dask-Yarn
provides an easy interface to quickly start, stop, and scale Dask clusters
natively from Python.

See `the documentation <http://yarn.dask.org>`_ for more information.


LICENSE
-------

New BSD. See the
`License File <https://github.com/dask/dask-yarn/blob/master/LICENSE.txt>`_.

.. |travis| image:: https://travis-ci.org/dask/dask-yarn.svg?branch=master
   :target: https://travis-ci.org/dask/dask-yarn
.. |pypi| image:: https://img.shields.io/pypi/v/dask-yarn.svg
   :target: https://pypi.org/project/dask-yarn/
.. |conda| image:: https://img.shields.io/conda/vn/conda-forge/dask-yarn.svg
   :target: https://anaconda.org/conda-forge/dask-yarn
.. |readthedocs| image:: https://readthedocs.org/projects/dask-yarn/badge/?version=latest
    :target: http://yarn.dask.org
